rm -f produced.out
rm -rf hello
rm -rf HelloWorld
rm -rf hello-world
rm -rf hello_world
rm -rf hello-exe
rm -rf lean-data
rm -rf 123-hello
rm -rf A-B-C-D
rm -rf meta
rm -rf qed
rm -rf mathlib_standards
